==> blancoNLpackGenerator-0.0.95-src.zip: src/blanco/xliff/stringgroup/BlancoXliffStateStringGroup.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.xliff.stringgroup;

/**
 * OASIS XLIFF state Agr[g̒`ςݕꗗ킵܂B
 */
public class BlancoXliffStateStringGroup {
    /**
     * No.1 :Indicates the terminating state.
     */
    public static final int FINAL = 1;

    /**
     * No.2 :Indicates only non-textual information needs adaptation.
     */
    public static final int NEEDS_ADAPTATION = 2;

    /**
     * No.3 :Indicates both text and non-textual information needs adaptation.
     */
    public static final int NEEDS_L10N = 3;

    /**
     * No.4 :Indicates only non-textual information needs review.
     */
    public static final int NEEDS_REVIEW_ADAPTATION = 4;

    /**
     * No.5 :Indicates both text and non-textual information needs review.
     */
    public static final int NEEDS_REVIEW_L10N = 5;

    /**
     * No.6 :Indicates that only the text of the item needs to be reviewed.
     */
    public static final int NEEDS_REVIEW_TRANSLATION = 6;

    /**
     * No.7 :Indicates that the item needs to be translated.
     */
    public static final int NEEDS_TRANSLATION = 7;

    /**
     * No.8 :Indicates that the item is new. For example, translation units that were not in a previous version of the document.
     */
    public static final int NEW = 8;

    /**
     * No.9 :Indicates that changes are reviewed and approved.
     */
    public static final int SIGNED_OFF = 9;

    /**
     * No.10 :Indicates that the item has been translated.
     */
    public static final int TRANSLATED = 10;

    /**
     * `BO[vȊO̕܂͒萔`̂́B
     */
    public static final int NOT_DEFINED = -1;

    /**
     * O[vɊ܂܂镶ł邩ǂ𔻒肵܂B
     *
     * @param argCheck `FbNsB
     * @return O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB
     */
    public boolean match(final String argCheck) {
        // No.1
        // :Indicates the terminating state.
        if ("final".equals(argCheck)) {
            return true;
        }
        // No.2
        // :Indicates only non-textual information needs adaptation.
        if ("needs-adaptation".equals(argCheck)) {
            return true;
        }
        // No.3
        // :Indicates both text and non-textual information needs adaptation.
        if ("needs-l10n".equals(argCheck)) {
            return true;
        }
        // No.4
        // :Indicates only non-textual information needs review.
        if ("needs-review-adaptation".equals(argCheck)) {
            return true;
        }
        // No.5
        // :Indicates both text and non-textual information needs review.
        if ("needs-review-l10n".equals(argCheck)) {
            return true;
        }
        // No.6
        // :Indicates that only the text of the item needs to be reviewed.
        if ("needs-review-translation".equals(argCheck)) {
            return true;
        }
        // No.7
        // :Indicates that the item needs to be translated.
        if ("needs-translation".equals(argCheck)) {
            return true;
        }
        // No.8
        // :Indicates that the item is new. For example, translation units that were not in a previous version of the document.
        if ("new".equals(argCheck)) {
            return true;
        }
        // No.9
        // :Indicates that changes are reviewed and approved.
        if ("signed-off".equals(argCheck)) {
            return true;
        }
        // No.10
        // :Indicates that the item has been translated.
        if ("translated".equals(argCheck)) {
            return true;
        }
        return false;
    }

    /**
     * O[vɊ܂܂镶ł邩ǂA啶ʂ肵܂B
     *
     * @param argCheck `FbNsB
     * @return O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB
     */
    public boolean matchIgnoreCase(final String argCheck) {
        // No.1
        // :Indicates the terminating state.
        if ("final".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.2
        // :Indicates only non-textual information needs adaptation.
        if ("needs-adaptation".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.3
        // :Indicates both text and non-textual information needs adaptation.
        if ("needs-l10n".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.4
        // :Indicates only non-textual information needs review.
        if ("needs-review-adaptation".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.5
        // :Indicates both text and non-textual information needs review.
        if ("needs-review-l10n".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.6
        // :Indicates that only the text of the item needs to be reviewed.
        if ("needs-review-translation".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.7
        // :Indicates that the item needs to be translated.
        if ("needs-translation".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.8
        // :Indicates that the item is new. For example, translation units that were not in a previous version of the document.
        if ("new".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.9
        // :Indicates that changes are reviewed and approved.
        if ("signed-off".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.10
        // :Indicates that the item has been translated.
        if ("translated".equalsIgnoreCase(argCheck)) {
            return true;
        }
        return false;
    }

    /**
     * 񂩂萔ɕϊ܂B
     *
     * 萔`̏ꍇ ^ꂽ񂪕O[vȌꍇɂ NOT_DEFINED ߂܂B
     *
     * @param argCheck ϊsB
     * @return 萔ɕϊ̒lB
     */
    public int convertToInt(final String argCheck) {
        // No.1
        // :Indicates the terminating state.
        if ("final".equals(argCheck)) {
            return FINAL;
        }
        // No.2
        // :Indicates only non-textual information needs adaptation.
        if ("needs-adaptation".equals(argCheck)) {
            return NEEDS_ADAPTATION;
        }
        // No.3
        // :Indicates both text and non-textual information needs adaptation.
        if ("needs-l10n".equals(argCheck)) {
            return NEEDS_L10N;
        }
        // No.4
        // :Indicates only non-textual information needs review.
        if ("needs-review-adaptation".equals(argCheck)) {
            return NEEDS_REVIEW_ADAPTATION;
        }
        // No.5
        // :Indicates both text and non-textual information needs review.
        if ("needs-review-l10n".equals(argCheck)) {
            return NEEDS_REVIEW_L10N;
        }
        // No.6
        // :Indicates that only the text of the item needs to be reviewed.
        if ("needs-review-translation".equals(argCheck)) {
            return NEEDS_REVIEW_TRANSLATION;
        }
        // No.7
        // :Indicates that the item needs to be translated.
        if ("needs-translation".equals(argCheck)) {
            return NEEDS_TRANSLATION;
        }
        // No.8
        // :Indicates that the item is new. For example, translation units that were not in a previous version of the document.
        if ("new".equals(argCheck)) {
            return NEW;
        }
        // No.9
        // :Indicates that changes are reviewed and approved.
        if ("signed-off".equals(argCheck)) {
            return SIGNED_OFF;
        }
        // No.10
        // :Indicates that the item has been translated.
        if ("translated".equals(argCheck)) {
            return TRANSLATED;
        }

        // Y萔܂łB
        return NOT_DEFINED;
    }

    /**
     * 萔當ɕϊ܂B
     *
     * 萔ƑΉÂɕϊ܂B
     *
     * @param argCheck ϊs萔B
     * @return ɕϊ̒lBNOT_DEFINED̏ꍇɂ͒0̕B
     */
    public String convertToString(final int argCheck) {
        // No.1
        // :Indicates the terminating state.
        if (argCheck == FINAL) {
            return "final";
        }
        // No.2
        // :Indicates only non-textual information needs adaptation.
        if (argCheck == NEEDS_ADAPTATION) {
            return "needs-adaptation";
        }
        // No.3
        // :Indicates both text and non-textual information needs adaptation.
        if (argCheck == NEEDS_L10N) {
            return "needs-l10n";
        }
        // No.4
        // :Indicates only non-textual information needs review.
        if (argCheck == NEEDS_REVIEW_ADAPTATION) {
            return "needs-review-adaptation";
        }
        // No.5
        // :Indicates both text and non-textual information needs review.
        if (argCheck == NEEDS_REVIEW_L10N) {
            return "needs-review-l10n";
        }
        // No.6
        // :Indicates that only the text of the item needs to be reviewed.
        if (argCheck == NEEDS_REVIEW_TRANSLATION) {
            return "needs-review-translation";
        }
        // No.7
        // :Indicates that the item needs to be translated.
        if (argCheck == NEEDS_TRANSLATION) {
            return "needs-translation";
        }
        // No.8
        // :Indicates that the item is new. For example, translation units that were not in a previous version of the document.
        if (argCheck == NEW) {
            return "new";
        }
        // No.9
        // :Indicates that changes are reviewed and approved.
        if (argCheck == SIGNED_OFF) {
            return "signed-off";
        }
        // No.10
        // :Indicates that the item has been translated.
        if (argCheck == TRANSLATED) {
            return "translated";
        }
        // `B
        if (argCheck == NOT_DEFINED) {
            return "";
        }

        // ɂY܂łB
        throw new IllegalArgumentException("^ꂽl(" + argCheck + ")͕O[v[BlancoXliffState]ł͒`ȂlłB");
    }
}

==> blancoNLpackGenerator-0.1.2-src.zip: src/blanco/xliff/stringgroup/BlancoXliffStateStringGroup.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.xliff.stringgroup;

/**
 * OASIS XLIFF state Agr[g̒`ςݕꗗ킵܂B
 */
public class BlancoXliffStateStringGroup {
    /**
     * No.1 :Indicates the terminating state.
     */
    public static final int FINAL = 1;

    /**
     * No.2 :Indicates only non-textual information needs adaptation.
     */
    public static final int NEEDS_ADAPTATION = 2;

    /**
     * No.3 :Indicates both text and non-textual information needs adaptation.
     */
    public static final int NEEDS_L10N = 3;

    /**
     * No.4 :Indicates only non-textual information needs review.
     */
    public static final int NEEDS_REVIEW_ADAPTATION = 4;

    /**
     * No.5 :Indicates both text and non-textual information needs review.
     */
    public static final int NEEDS_REVIEW_L10N = 5;

    /**
     * No.6 :Indicates that only the text of the item needs to be reviewed.
     */
    public static final int NEEDS_REVIEW_TRANSLATION = 6;

    /**
     * No.7 :Indicates that the item needs to be translated.
     */
    public static final int NEEDS_TRANSLATION = 7;

    /**
     * No.8 :Indicates that the item is new. For example, translation units that were not in a previous version of the document.
     */
    public static final int NEW = 8;

    /**
     * No.9 :Indicates that changes are reviewed and approved.
     */
    public static final int SIGNED_OFF = 9;

    /**
     * No.10 :Indicates that the item has been translated.
     */
    public static final int TRANSLATED = 10;

    /**
     * No.12 :blancoƎ: r[ς݁B
     */
    public static final int X_REVIEWED = 11;

    /**
     * No.13 :blancoƎ: ^[QbgB
     */
    public static final int X_NOTARGET = 12;

    /**
     * `BO[vȊO̕܂͒萔`̂́B
     */
    public static final int NOT_DEFINED = -1;

    /**
     * O[vɊ܂܂镶ł邩ǂ𔻒肵܂B
     *
     * @param argCheck `FbNsB
     * @return O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB
     */
    public boolean match(final String argCheck) {
        // No.1
        // :Indicates the terminating state.
        if ("final".equals(argCheck)) {
            return true;
        }
        // No.2
        // :Indicates only non-textual information needs adaptation.
        if ("needs-adaptation".equals(argCheck)) {
            return true;
        }
        // No.3
        // :Indicates both text and non-textual information needs adaptation.
        if ("needs-l10n".equals(argCheck)) {
            return true;
        }
        // No.4
        // :Indicates only non-textual information needs review.
        if ("needs-review-adaptation".equals(argCheck)) {
            return true;
        }
        // No.5
        // :Indicates both text and non-textual information needs review.
        if ("needs-review-l10n".equals(argCheck)) {
            return true;
        }
        // No.6
        // :Indicates that only the text of the item needs to be reviewed.
        if ("needs-review-translation".equals(argCheck)) {
            return true;
        }
        // No.7
        // :Indicates that the item needs to be translated.
        if ("needs-translation".equals(argCheck)) {
            return true;
        }
        // No.8
        // :Indicates that the item is new. For example, translation units that were not in a previous version of the document.
        if ("new".equals(argCheck)) {
            return true;
        }
        // No.9
        // :Indicates that changes are reviewed and approved.
        if ("signed-off".equals(argCheck)) {
            return true;
        }
        // No.10
        // :Indicates that the item has been translated.
        if ("translated".equals(argCheck)) {
            return true;
        }
        // No.12
        // :blancoƎ: r[ς݁B
        if ("x-reviewed".equals(argCheck)) {
            return true;
        }
        // No.13
        // :blancoƎ: ^[QbgB
        if ("x-notarget".equals(argCheck)) {
            return true;
        }
        return false;
    }

    /**
     * O[vɊ܂܂镶ł邩ǂA啶ʂ肵܂B
     *
     * @param argCheck `FbNsB
     * @return O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB
     */
    public boolean matchIgnoreCase(final String argCheck) {
        // No.1
        // :Indicates the terminating state.
        if ("final".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.2
        // :Indicates only non-textual information needs adaptation.
        if ("needs-adaptation".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.3
        // :Indicates both text and non-textual information needs adaptation.
        if ("needs-l10n".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.4
        // :Indicates only non-textual information needs review.
        if ("needs-review-adaptation".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.5
        // :Indicates both text and non-textual information needs review.
        if ("needs-review-l10n".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.6
        // :Indicates that only the text of the item needs to be reviewed.
        if ("needs-review-translation".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.7
        // :Indicates that the item needs to be translated.
        if ("needs-translation".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.8
        // :Indicates that the item is new. For example, translation units that were not in a previous version of the document.
        if ("new".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.9
        // :Indicates that changes are reviewed and approved.
        if ("signed-off".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.10
        // :Indicates that the item has been translated.
        if ("translated".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.12
        // :blancoƎ: r[ς݁B
        if ("x-reviewed".equalsIgnoreCase(argCheck)) {
            return true;
        }
        // No.13
        // :blancoƎ: ^[QbgB
        if ("x-notarget".equalsIgnoreCase(argCheck)) {
            return true;
        }
        return false;
    }

    /**
     * 񂩂萔ɕϊ܂B
     *
     * 萔`̏ꍇ ^ꂽ񂪕O[vȌꍇɂ NOT_DEFINED ߂܂B
     *
     * @param argCheck ϊsB
     * @return 萔ɕϊ̒lB
     */
    public int convertToInt(final String argCheck) {
        // No.1
        // :Indicates the terminating state.
        if ("final".equals(argCheck)) {
            return FINAL;
        }
        // No.2
        // :Indicates only non-textual information needs adaptation.
        if ("needs-adaptation".equals(argCheck)) {
            return NEEDS_ADAPTATION;
        }
        // No.3
        // :Indicates both text and non-textual information needs adaptation.
        if ("needs-l10n".equals(argCheck)) {
            return NEEDS_L10N;
        }
        // No.4
        // :Indicates only non-textual information needs review.
        if ("needs-review-adaptation".equals(argCheck)) {
            return NEEDS_REVIEW_ADAPTATION;
        }
        // No.5
        // :Indicates both text and non-textual information needs review.
        if ("needs-review-l10n".equals(argCheck)) {
            return NEEDS_REVIEW_L10N;
        }
        // No.6
        // :Indicates that only the text of the item needs to be reviewed.
        if ("needs-review-translation".equals(argCheck)) {
            return NEEDS_REVIEW_TRANSLATION;
        }
        // No.7
        // :Indicates that the item needs to be translated.
        if ("needs-translation".equals(argCheck)) {
            return NEEDS_TRANSLATION;
        }
        // No.8
        // :Indicates that the item is new. For example, translation units that were not in a previous version of the document.
        if ("new".equals(argCheck)) {
            return NEW;
        }
        // No.9
        // :Indicates that changes are reviewed and approved.
        if ("signed-off".equals(argCheck)) {
            return SIGNED_OFF;
        }
        // No.10
        // :Indicates that the item has been translated.
        if ("translated".equals(argCheck)) {
            return TRANSLATED;
        }
        // No.12
        // :blancoƎ: r[ς݁B
        if ("x-reviewed".equals(argCheck)) {
            return X_REVIEWED;
        }
        // No.13
        // :blancoƎ: ^[QbgB
        if ("x-notarget".equals(argCheck)) {
            return X_NOTARGET;
        }

        // Y萔܂łB
        return NOT_DEFINED;
    }

    /**
     * 萔當ɕϊ܂B
     *
     * 萔ƑΉÂɕϊ܂B
     *
     * @param argCheck ϊs萔B
     * @return ɕϊ̒lBNOT_DEFINED̏ꍇɂ͒0̕B
     */
    public String convertToString(final int argCheck) {
        // No.1
        // :Indicates the terminating state.
        if (argCheck == FINAL) {
            return "final";
        }
        // No.2
        // :Indicates only non-textual information needs adaptation.
        if (argCheck == NEEDS_ADAPTATION) {
            return "needs-adaptation";
        }
        // No.3
        // :Indicates both text and non-textual information needs adaptation.
        if (argCheck == NEEDS_L10N) {
            return "needs-l10n";
        }
        // No.4
        // :Indicates only non-textual information needs review.
        if (argCheck == NEEDS_REVIEW_ADAPTATION) {
            return "needs-review-adaptation";
        }
        // No.5
        // :Indicates both text and non-textual information needs review.
        if (argCheck == NEEDS_REVIEW_L10N) {
            return "needs-review-l10n";
        }
        // No.6
        // :Indicates that only the text of the item needs to be reviewed.
        if (argCheck == NEEDS_REVIEW_TRANSLATION) {
            return "needs-review-translation";
        }
        // No.7
        // :Indicates that the item needs to be translated.
        if (argCheck == NEEDS_TRANSLATION) {
            return "needs-translation";
        }
        // No.8
        // :Indicates that the item is new. For example, translation units that were not in a previous version of the document.
        if (argCheck == NEW) {
            return "new";
        }
        // No.9
        // :Indicates that changes are reviewed and approved.
        if (argCheck == SIGNED_OFF) {
            return "signed-off";
        }
        // No.10
        // :Indicates that the item has been translated.
        if (argCheck == TRANSLATED) {
            return "translated";
        }
        // No.12
        // :blancoƎ: r[ς݁B
        if (argCheck == X_REVIEWED) {
            return "x-reviewed";
        }
        // No.13
        // :blancoƎ: ^[QbgB
        if (argCheck == X_NOTARGET) {
            return "x-notarget";
        }
        // `B
        if (argCheck == NOT_DEFINED) {
            return "";
        }

        // ɂY܂łB
        throw new IllegalArgumentException("^ꂽl(" + argCheck + ")͕O[v[BlancoXliffState]ł͒`ȂlłB");
    }
}
